/*********************************************
Project : Commande de l'antenne (TP2)
Version : 1
Mise  jour: 28/10/2010
Author  : Philippe Mariano
Company : LYCEE Pierre Emile MARTIN
Comments: La commande de l'antenne est
mmorise par les BP S1, S2, S3 et S4
Cible: Carte SSI
Chip type           : ATMEGA8535
Clock frequency     : 8,000000 MHz
Memory model        : Small
Internal SRAM size  : 512
External SRAM size  : 0
Data Stack size     : 128
*********************************************/

#include <mega8535.h>

// Bibliothques non gnres par Wizard (rajoutes manuellement)
// -----------------------------------------------------------------------------------------------------
#include <ssi2.h>      // contient les fonctions Lire_BP, Affiche_LCD
#include <delay.h>    // contient la fonction delay_ms
#include <stdio.h>    // contient la fonction sprintf

// Etats du graphe des transitions
// -----------------------------------------------------------------------------------------------------
#define Arret	        0
#define Horaire 	    1
#define AntiHoraire     2

// Alphanumeric LCD Module functions
#asm
   .equ __lcd_port=0x15
#endasm
#include <lcd.h>

// =====================================================================================================
// Programme principal
// =====================================================================================================
void main(void)
{  // Dbut prog principal
// Declare your local variables here
// -----------------------------------------------------------------------------------------------------
// type 	nom              		Description
// -----------------------------------------------------------------------------------------------------
char display_buffer_ligne0[17]; 	// tampon ligne 0 de l'afficheur
char display_buffer_ligne1[17]; 	// tampon ligne 1 de l'afficheur
unsigned char Aff=0, Aff_1=0;
unsigned char BP, Moteur, Etat;
// -----------------------------------------------------------------------------------------------------
//-------------------------------------------------------------------------------------------------------
//					Configuration des ports d'E/S
//-------------------------------------------------------------------------------------------------------
// Port A initialization
PORTA=0x3F; 		        // ne pas modifier cette valeur
DDRA=0x00;

// Port B initialization
PORTB=0x00;                 // ne pas modifier cette valeur
DDRB=0x1f;
//------------------------------------------------------------------------------------------------------
// LCD module initialization
lcd_init(16);
// --------------------------------------- Message d'accueil -------------------------------------------
sprintf(display_buffer_ligne0,"  TP2 PARABOLE  ");
sprintf(display_buffer_ligne1,"   SIMULATION   ");
Affiche_LCD(display_buffer_ligne0,display_buffer_ligne1);
delay_ms(3000);
// -----------------------------------------------------------------------------------------------------
sprintf(display_buffer_ligne0,"   PROG CYCLE   ");
// -----------------------------------------------------------------------------------------------------
// Initialisation du graphe et des sorties
Etat = Arret; Moteur = 0;
// -----------------------------------------------------------------------------------------------------
// =====================================================================================================
// Boucle principale
// =====================================================================================================
while(1)  // Rpter toujours
 {
//-------------------------------------------------------------------------------------------------------
// REMARQUES:
// L'tat logique actif des BP de la carte SSI est 0 : les bits du Port A sont donc inverss par ~
// La commande du sens horaire se fait avec le BP ECHAP     (S3 sur le systme)
// L'arrt lors de la rotation en sens horaire se fait par OK (S2 sur le systme)
// La commande du sens anti-horaire se fait avec le BP SET  (S1 sur le systme)
// L'arrt lors de la rotation en sens anti-horaire se fait par DEC (S4 sur le systme)
//-------------------------------------------------------------------------------------------------------
   BP = (~PINA & 0b00011110);   // Lecture des entres. Pour mmoire: O 0 0 0 S4 S2 S3 S1 0

   switch (Etat) // dbut selon
   { // Etat Arret
     case Arret: Moteur = 0;
               if (BP == 2)	Etat = Horaire;
                    else if (BP == 4)	Etat = AntiHoraire;
                        else Etat = Arret;
     break;

     // Etat Descendre
     case Horaire: Moteur = 1;  	                     // <-   complter
                if (BP == 8) Etat= Arret;		  	     // <-   complter
      		        else Etat = Horaire;                 // <-   complter
     break;

     // Etat Monter
     case AntiHoraire: Moteur = 2;                      // <-   complter
      		if (BP == 16)	Etat = Arret;               // <-   complter
      		        else Etat = AntiHoraire;	        // <-   complter
     break;

     default : Etat = Arret;
    } // fin selon

    PORTB = Moteur;
//-------------------------------------------------------------------------------------------------------
//-------------------------------------------------------------------------------------------------------
// 				Gestion de l'affichage
//-------------------------------------------------------------------------------------------------------
        if (Etat==Horaire) {sprintf(display_buffer_ligne1,"  Rotation : H  ");Aff=0;}
       	    else  if (Etat==Arret) {sprintf(display_buffer_ligne1,"  Arret Moteur  ");Aff=1;}
       		    else {sprintf(display_buffer_ligne1,"  Rotation : AH ");Aff=2;}

       if (Aff != Aff_1) {Affiche_LCD(display_buffer_ligne0,display_buffer_ligne1);Aff_1=Aff;}
 };// fin rpter toujours
 //-------------------------------------------------------------------------------------------------------
}// fin prog principal
// =====================================================================================================